@@ -157,7 +157,10 @@ where
                             op: op!("!"), arg, ..
                         }) => arg.is_lit(),
                         Expr::This(..) => usage.is_fn_local,
-                        Expr::Arrow(arr) => is_arrow_simple_enough_for_copy(arr),
+                        Expr::Arrow(arr) => {
+                            !(usage.used_as_arg && usage.ref_count > 1)
+                                && is_arrow_simple_enough_for_copy(arr)
+                        }
                         _ => false,
                     }
                 {
@@ -251,7 +254,7 @@ where
                     }
 
                     if usage.used_as_arg && !usage.is_fn_local {
-                        if let Expr::Fn(..) = &**init {
+                        if let Expr::Fn(..) | Expr::Arrow(..) = &**init {
                             return;
                         }
                     }
@@ -466,7 +469,12 @@ where
 
         if let Some(usage) = self.data.vars.get(&i.to_id()) {
             if usage.declared_as_catch_param {
-                log_abort!("inline: [x] Declared as a catch parameter");
+                log_abort!("inline: Declared as a catch parameter");
+                return;
+            }
+
+            if usage.used_as_arg && usage.ref_count > 1 {
+                log_abort!("inline: Used as an arugment");
                 return;
             }
 
